@@ -62,6 +62,7 @@ BOARDS = [
     Boards.STM32F469I_DISCO.value,
     Boards.STM32H747I_DISCO.value,
     Boards.STM32F407G_DISCO.value,
+    Boards.STM32F411E_DISCO.value,
     Boards.IMXRT1050_EVKB.value,
 ]
 
@@ -69,6 +70,7 @@ AUDIO_DEBUG_RECORD_DURATION_SEC = {
     Boards.STM32F469I_DISCO.value: 3,
     Boards.STM32H747I_DISCO.value: 3,
     Boards.STM32F407G_DISCO.value: 1,
+    Boards.STM32F411E_DISCO.value: 1,
     Boards.IMXRT1050_EVKB.value: 3
 }
 AUDIO_DEBUG_FFT_WINDOW_SIZE = 512
@@ -191,7 +193,13 @@ class PicovoiceApp(tk.Tk):
         self._menu_bar.add_cascade(label="Help", menu=self._help_menu, underline=0)
         self.config(menu=self._menu_bar)
 
-        self._status_bar = tk.Label(master=self, text='', bg=SOFT_GREY, bd=1, relief=tk.FLAT, anchor=tk.W)
+        self._status_bar = ttk.Label(
+            self,
+            text='',
+            borderwidth=1,
+            relief='flat',
+            background=FRAME_COMMON_PARAMS['background'],
+            anchor=tk.W)
         self._status_bar.grid(row=1, column=0, sticky='swe')
 
         self.protocol("WM_DELETE_WINDOW", self._destroy)
@@ -282,7 +290,7 @@ class UploadFirmwareFrame(tk.Frame, PicoFrame):
         self._boards_tree_view = ttk.Treeview(
             self,
             cursor='hand2',
-            height=4,
+            height=6,
             show='tree')
         for i, x in enumerate(BOARDS):
             self._boards_tree_view.insert('', 'end', text=x)
@@ -354,6 +362,7 @@ class UploadFirmwareFrame(tk.Frame, PicoFrame):
 
     def connection_error(self):
         messagebox.showerror(title='Error', message='Connection to %s was lost' % self._board)
+        self.master.update_status_bar('')
         self.master.draw_upload_firmware_frame()
 
     def draw_next_frame(self):
@@ -375,6 +384,7 @@ class UploadModelsFrame(tk.Frame, PicoFrame):
         self._message_thread = None
         self._is_connecting_done = False
 
+        self._uuid = None
         self._is_uploading_done = False
         self._is_responded = False
         self._selected_models = dict(porcupine=DEFAULT_PORCUPINE_MODEL, rhino=DEFAULT_RHINO_MODEL)
@@ -868,6 +878,7 @@ class ControlPanel(tk.Frame, PicoFrame):
 
     def connection_error(self):
         messagebox.showerror(title='Error', message='Connection to %s was lost' % self._board)
+        self.master.update_status_bar('')
         self.master.draw_upload_firmware_frame()
 
     def draw_next_frame(self):
